# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['spinta',
 'spinta.accesslog',
 'spinta.backends',
 'spinta.backends.fs',
 'spinta.backends.fs.commands',
 'spinta.backends.memory',
 'spinta.backends.memory.commands',
 'spinta.backends.mongo',
 'spinta.backends.mongo.commands',
 'spinta.backends.mongo.types',
 'spinta.backends.mongo.types.array',
 'spinta.backends.mongo.types.file',
 'spinta.backends.mongo.types.object',
 'spinta.backends.postgresql',
 'spinta.backends.postgresql.commands',
 'spinta.backends.postgresql.helpers',
 'spinta.backends.postgresql.types',
 'spinta.backends.postgresql.types.array',
 'spinta.backends.postgresql.types.file',
 'spinta.backends.postgresql.types.object',
 'spinta.backends.postgresql.types.ref',
 'spinta.cli',
 'spinta.cli.helpers',
 'spinta.commands',
 'spinta.commands.formats',
 'spinta.core',
 'spinta.datasets',
 'spinta.datasets.backends',
 'spinta.datasets.backends.csv',
 'spinta.datasets.backends.frictionless',
 'spinta.datasets.backends.frictionless.commands',
 'spinta.datasets.backends.sql',
 'spinta.datasets.backends.sql.commands',
 'spinta.datasets.backends.sqldump',
 'spinta.datasets.backends.sqldump.commands',
 'spinta.datasets.backends.sqldump.ufuncs',
 'spinta.datasets.commands',
 'spinta.datasets.keymaps',
 'spinta.dimensions',
 'spinta.dimensions.commands',
 'spinta.dimensions.prefix',
 'spinta.hacks',
 'spinta.manifests',
 'spinta.manifests.backend',
 'spinta.manifests.backend.commands',
 'spinta.manifests.commands',
 'spinta.manifests.internal',
 'spinta.manifests.internal.commands',
 'spinta.manifests.tabular',
 'spinta.manifests.tabular.commands',
 'spinta.manifests.yaml',
 'spinta.manifests.yaml.commands',
 'spinta.migrations',
 'spinta.migrations.schema',
 'spinta.testing',
 'spinta.types',
 'spinta.types.array',
 'spinta.types.file',
 'spinta.types.object',
 'spinta.types.ref',
 'spinta.utils']

package_data = \
{'': ['*'], 'spinta': ['manifest/*', 'manifest/_schema/*', 'templates/*']}

install_requires = \
['aiofiles',
 'alembic',
 'asyncpg',
 'authlib>=0.11,<0.12',
 'boto3',
 'click',
 'frictionless[sql]>=3.48.0,<4.0.0',
 'gunicorn',
 'jinja2',
 'jsonpatch',
 'lark-parser',
 'lxml',
 'msgpack',
 'multipledispatch',
 'phonenumbers',
 'psycopg2-binary',
 'pymongo',
 'python-multipart',
 'pytz',
 'requests',
 'ruamel.yaml',
 'setuptools',
 'setuptools-scm',
 'sqlalchemy',
 'sqlparse',
 'starlette',
 'texttable',
 'toposort',
 'tqdm',
 'typer[all]>=0.3.2,<0.4.0',
 'ujson',
 'unidecode',
 'uvicorn',
 'xlrd']

entry_points = \
{'console_scripts': ['spinta = spinta.cli.main:app']}

setup_kwargs = {
    'name': 'spinta',
    'version': '0.1.7',
    'description': 'A platform for describing, extracting, transforming and serving open data.\n',
    'long_description': '.. default-role:: literal\n\nThis data store allows you to take full control of your data.\n\n.. image:: https://gitlab.com/atviriduomenys/spinta/badges/master/pipeline.svg\n   :target: https://gitlab.com/atviriduomenys/spinta/commits/master\n\n.. image:: https://gitlab.com/atviriduomenys/spinta/badges/master/coverage.svg\n   :target: https://gitlab.com/atviriduomenys/spinta/commits/master\n\n\nFeatures\n========\n\n- Support for multiple backends, currently supported backends: PostgreSQL.\n\n- Declarative data descriptors using YAML format.\n\n- Change history, you can restore and view historical data.\n\n- Import data from external data sources.\n\n\nConfiguration\n=============\n\nSpinta reads configuration values from these sources, listed in priority order:\n\n- Command line arguments passed as `-o key=value`.\n\n- From environment variables, first looking into `SPINTA_<env>_<name>`, then to\n  `SPINTA_<name>`. `<env>` is taken from `SPINTA_ENV`.\n\n- From environment file `.env`, using same naming as environment variables.\n\n- From default configuration, specified by `SPINTA_CONFIG`, which defaults to\n  `spinta.config:CONFIG`.\n\nWhen running tests, Spinta uses `test` as environment name, so if you need to\nset configuration parameters only for tests, use `SPINTA_TEST_<name>`. For\nexample, if you have these environment variables set::\n\n   SPINTA_BACKENDS_DEFAULT_DSN=a\n   SPINTA_TEST_BACKENDS_DEFAULT_DSN=b\n\nThen, when you run tests, `b` will be used, in all other cases, `a` will be\nused.\n',
    'author': 'Mantas Zimnickas',
    'author_email': 'sirexas@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/atviriduomenys/spinta',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
